@@ -8,20 +8,21 @@ var css_browser_selector = function() {
 		ua=navigator.userAgent.toLowerCase(),
 		is=function(t){ return ua.indexOf(t) != -1; },
 		h=document.firstChild;
-		b=(!(/opera|webtv/i.test(ua))&&/msie (\d)/.test(ua)) ? ('ie ie'+RegExp.$1) :
+    var b=(!(/opera|webtv/i.test(ua))&&/msie (\d)/.test(ua)) ? ('ie ie'+RegExp.$1) :
             is('gecko/') ? 'gecko' : 
             is('opera/9') ? 'opera opera9' :
             /opera (\d)/.test(ua) ? 'opera opera'+RegExp.$1 : 
             is('konqueror') ? 'konqueror' : 
             is('applewebkit/') ? 'webkit safari' : 
             is('mozilla/') ? 'gecko' : '',
-		os=(is('x11')||is('linux')) ? ' linux' : 
+        os=(is('x11')||is('linux')) ? ' linux' : 
             is('mac') ? ' mac':
             is('win') ? ' win':'';
-        bm= /firefox\/(\d+)\.(\d+)/.test(ua) ? 
+    var bm= /firefox\/(\d+)\.(\d+)/.test(ua) ? 
                     ' firefox firefox'+RegExp.$1+
                     ' firefox'+RegExp.$1+'_'+RegExp.$2 :
             is('explorer') ? ' explorer' : '';
 	var c=b+os+bm+' js';
 	h.className += h.className?' '+c:c;
+    return c;
 }();
\ No newline at end of file
